
var bv = BrainVoyager; // use short symbol to access BrainVoyager API

var scriptObj = new Object;

scriptObj.dialogFileName   = "ExampleGUIPlugin.ui";  // specify name of file that will be used by BV to create your UI
scriptObj.dialogAccessName = "PluginDialog";         // specify the name you want to use for accessing your UI

scriptObj.initDlg = function()
{
	var dlg = this.PluginDialog; // less to write

	dlg.windowTitle = "Example GUI Plugin"; // use to change dialog title

	dlg.intensityRangeGroupBox.fromIntensitySpinBox.maximum = 255; // set max allowed value of "From" spin box
	dlg.intensityRangeGroupBox.toIntensitySpinBox.maximum = 255;   // set max allowed value of "To" spin box
	dlg.intensityRangeGroupBox.fromIntensitySpinBox.value = 0;     // change value to "0" as default
	dlg.intensityRangeGroupBox.toIntensitySpinBox.value = 255;     // change value to "255" as default

	// connec UI elements to script funcctions - you need to know the names of your elements (check your definition)
	dlg.invertButton.clicked.connect(this, this.onInvert);
	dlg.undoButton.clicked.connect(this, this.onUndo);
	dlg.quitButton.clicked.connect(this, this.onQuit);
	dlg.countVoxelsGroupBox.countVoxelsButton.clicked.connect(this, this.onCountVoxels);
}

scriptObj.onQuit = function()
{
	bv.PrintToLog("Script>  Dialog's Quit button clicked - closing dialog");

	this.PluginDialog.close();
}

scriptObj.onUndo = function()
{
	bv.PrintToLog("Script>  Dialog's Undo button clicked - restoring original VMR intensities");

	bv.SetPluginStringParameter("Command", "Undo");

	bv.ExecutePlugin();
}

scriptObj.onInvert = function()
{
	var dlg = this.PluginDialog;

	bv.PrintToLog("Script>  Dialog's Invert button clicked");

	bv.SetPluginStringParameter("Command", "Invert");
	bv.SetPluginIntParameter("MinimumIntensity", dlg.intensityRangeGroupBox.fromIntensitySpinBox.value);
	bv.SetPluginIntParameter("MaximumIntensity", dlg.intensityRangeGroupBox.toIntensitySpinBox.value);

	bv.ExecutePlugin();
}

scriptObj.onCountVoxels = function()
{
	var dlg = this.PluginDialog;

	bv.PrintToLog("Script>  Dialog's Count Voxels button clicked");

	bv.SetPluginStringParameter("Command", "CountVoxels");
	bv.SetPluginIntParameter("MinimumIntensity", dlg.intensityRangeGroupBox.fromIntensitySpinBox.value);
	bv.SetPluginIntParameter("MaximumIntensity", dlg.intensityRangeGroupBox.toIntensitySpinBox.value);

	bv.ExecutePlugin();

	var nrOfVoxels = bv.GetPluginIntParameter("NumberOfCountedVoxels"); // get result from plugin

	dlg.countVoxelsGroupBox.numberOfVoxelsEdit.text = nrOfVoxels;
}

// It is important to return script object containing properties and functions to be called from BrainVoyager
//
returnScriptObj = function()
{
	return scriptObj;
}
returnScriptObj(); // we call this at the end to return created script object to BrainVoyager
